@@ -34,12 +34,13 @@
 #include <QScreen>
 
 #include <DPlatformWindowHandle>
+#include <com_deepin_dde_daemon_dock.h>
 #include <com_deepin_daemon_display.h>
 #include <com_deepin_daemon_display_monitor.h>
-#include "notification/dbusdockinterface.h"
 
 using DisplayInter = com::deepin::daemon::Display;
 using MonitorInter = com::deepin::daemon::display::Monitor;
+using DockInter = com::deepin::dde::daemon::Dock;
 
 DGUI_USE_NAMESPACE
 
@@ -92,18 +93,17 @@ void Container::setContent(QWidget *content)
 void Container::moveToCenter()
 {
     QRect displayRect;
-    qreal ratio = qApp->primaryScreen()->devicePixelRatio();
     DisplayInter displayInter("com.deepin.daemon.Display", "/com/deepin/daemon/Display", QDBusConnection::sessionBus());
     QList<QDBusObjectPath> screenList = displayInter.monitors();
 
-    for (const auto &screen : screenList) {
-        MonitorInter monitor("com.deepin.daemon.Display", screen.path(), QDBusConnection::sessionBus());
-        QRect monitorRect(monitor.x(), monitor.y(), monitor.width(), monitor.height());
-        DBusDockInterface dockInter;
-        if (monitor.enabled() && monitorRect.contains(dockInter.geometry())) {
-            qDebug() << " screen display : " << screen.path();
-            displayRect = QRect(monitorRect.x(), monitorRect.y(),
-                                monitorRect.width() / ratio, monitorRect.height() / ratio);
+    DockInter dockInter("com.deepin.dde.daemon.Dock", "/com/deepin/dde/daemon/Dock", QDBusConnection::sessionBus(), this);
+    QRect dockRect = dockInter.frontendWindowRect();
+    for (auto *screen : qApp->screens()) {
+        const QRect &screenRect = screen->geometry();
+        const QRect &rect = QRect(screenRect.topLeft(), screenRect.size());
+
+        if (rect.contains(dockRect.topLeft())) {
+            displayRect = rect;
             break;
         }
     }
