@@ -173,29 +173,25 @@ void Manager::ShowOSD(const QString &osd)
 
 void Manager::updateUI()
 {
-    if (!m_currentProvider) return;
+    if (!m_currentProvider)
+        return;
 
-    if (m_model->provider() != m_currentProvider) {
-        m_model->setProvider(m_currentProvider);
-        m_delegate->setProvider(m_currentProvider);
-        m_listview->setFlow(m_currentProvider->flow());
-        m_listview->setCurrentIndex(m_listview->model()->index(m_currentProvider->currentRow(), 0));
-        m_container->setContentsMargins(m_currentProvider->contentMargins());
-        m_container->setFixedSize(m_currentProvider->contentSize());
-        m_container->moveToCenter();
-    }
-    if (!m_container->isVisible()) { // 相同模块如果osd已经显示，就不更新OSD位置，避免频繁切换在性能较弱的机器上出现闪烁
-        m_model->setProvider(m_currentProvider);
-        m_listview->setCurrentIndex(m_listview->model()->index(m_currentProvider->currentRow(), 0));
-        m_container->setFixedSize(m_currentProvider->contentSize());
-        m_container->moveToCenter();
-    }
+    m_model->setProvider(m_currentProvider);
+    m_delegate->setProvider(m_currentProvider);
+    m_listview->setFlow(m_currentProvider->flow());
+    m_listview->setCurrentIndex(m_listview->model()->index(m_currentProvider->currentRow(), 0));
+    m_container->setContentsMargins(m_currentProvider->contentMargins());
+    m_container->setFixedSize(m_currentProvider->contentSize());
+    m_container->moveToCenter();
 }
 
 void Manager::doneSetting()
 {
-    if (qApp->queryKeyboardModifiers().testFlag(Qt::MetaModifier)) {
-        return m_timer->start();
+    // wayland下meta键的MetaModifier事件依赖于按键事件，会先收到按键事件，随后才收到Modifier，这里应用自己规避
+    if (!QGuiApplication::platformName().startsWith("wayland", Qt::CaseInsensitive)) {
+        if (qApp->queryKeyboardModifiers().testFlag(Qt::MetaModifier)) {
+            return m_timer->start();
+        }
     }
 
     m_container->hide();
