@@ -3,7 +3,9 @@
 #include <QApplication>
 #include <QDebug>
 
-#define private public
+#ifdef QT_DEBUG
+#include <sanitizer/asan_interface.h>
+#endif
 
 int main(int argc, char *argv[])
 {
@@ -13,5 +15,10 @@ int main(int argc, char *argv[])
     ::testing::InitGoogleTest(&argc, argv);
     int ret = RUN_ALL_TESTS();
     qDebug() << "end dde-warning-dialog test cases ..............";
+    
+#ifdef QT_DEBUG
+    __sanitizer_set_report_path("asan_dde-warning-dialog.log");
+#endif
+
     return ret;
 }
